Index: ash/drag_drop/drag_drop_controller.h |
diff --git a/ash/drag_drop/drag_drop_controller.h b/ash/drag_drop/drag_drop_controller.h |
index a23ed913f2ad46407807b3fc94b0f7812a5a2b18..ec5cac1bf8359715f6e962793a56357283e27598 100644 |
--- a/ash/drag_drop/drag_drop_controller.h |
+++ b/ash/drag_drop/drag_drop_controller.h |
@@ -10,10 +10,10 @@ |
#include "base/memory/weak_ptr.h" |
#include "ui/aura/client/drag_drop_client.h" |
#include "ui/aura/window_observer.h" |
-#include "ui/base/animation/animation_delegate.h" |
#include "ui/base/dragdrop/os_exchange_data.h" |
#include "ui/base/events/event_constants.h" |
#include "ui/base/events/event_handler.h" |
+#include "ui/gfx/animation/animation_delegate.h" |
#include "ui/gfx/rect.h" |
namespace aura { |
@@ -21,7 +21,7 @@ class RootWindow; |
class Window; |
} |
-namespace ui { |
+namespace gfx { |
class LinearAnimation; |
} |
@@ -40,7 +40,7 @@ class DragImageView; |
class ASH_EXPORT DragDropController |
: public aura::client::DragDropClient, |
public ui::EventHandler, |
- public ui::AnimationDelegate, |
+ public gfx::AnimationDelegate, |
public aura::WindowObserver { |
public: |
DragDropController(); |
@@ -78,10 +78,10 @@ class ASH_EXPORT DragDropController |
// Helper method to create a LinearAnimation object that will run the drag |
// cancel animation. Caller take ownership of the returned object. Protected |
// for testing. |
- virtual ui::LinearAnimation* CreateCancelAnimation( |
+ virtual gfx::LinearAnimation* CreateCancelAnimation( |
int duration, |
int frame_rate, |
- ui::AnimationDelegate* delegate); |
+ gfx::AnimationDelegate* delegate); |
// Actual implementation of |DragCancel()|. protected for testing. |
virtual void DoDragCancel(int drag_cancel_animation_duration_ms); |
@@ -89,10 +89,10 @@ class ASH_EXPORT DragDropController |
private: |
friend class ash::test::DragDropControllerTest; |
- // Overridden from ui::AnimationDelegate: |
- virtual void AnimationEnded(const ui::Animation* animation) OVERRIDE; |
- virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE; |
- virtual void AnimationCanceled(const ui::Animation* animation) OVERRIDE; |
+ // Overridden from gfx::AnimationDelegate: |
+ virtual void AnimationEnded(const gfx::Animation* animation) OVERRIDE; |
+ virtual void AnimationProgressed(const gfx::Animation* animation) OVERRIDE; |
+ virtual void AnimationCanceled(const gfx::Animation* animation) OVERRIDE; |
// Helper method to start drag widget flying back animation. |
void StartCanceledAnimation(int animation_duration_ms); |
@@ -115,7 +115,7 @@ class ASH_EXPORT DragDropController |
gfx::Rect drag_image_initial_bounds_for_cancel_animation_; |
gfx::Rect drag_image_final_bounds_for_cancel_animation_; |
- scoped_ptr<ui::LinearAnimation> cancel_animation_; |
+ scoped_ptr<gfx::LinearAnimation> cancel_animation_; |
// Window that started the drag. |
aura::Window* drag_source_window_; |